parse_filter_directives

Function parse_filter_directives 

pub fn parse_filter_directives(
    directives: &str,
) -> Result<Targets, GenericError>
Parses a comma-separated list of log filter directives.

Each directive is a bare level (info), which sets the default level for all targets, or a target with a level (saluki=debug), which applies to that target and any target nested under it (for example, saluki::io). A bare target (saluki) enables all levels for that target. Empty directives are ignored, so an input with no directives disables all logging.

Errors

If any directive is malformed, or uses span or field filters (target[span{field=value}]=level), an error is returned.